@@ -3,9 +3,9 @@
 #' This function prepares objects for visualisation by returning a list of
 #' layers with data and geoms that can be easily plotted using for instance
 #' `ggplot2`. See the documentation for your object's class:
-#' \itemize{
-#'  \item{\link[modelbased:visualisation_recipe.estimate_predicted]{modelbased} (`estimate_means`, `estimate_contrasts`, `estimate_slopes`, `estimate_predicted`, `estimate_grouplevel`)}
-#' }
+#'
+#'  - {[modelbased][modelbased::visualisation_recipe.estimate_predicted] (`estimate_means`, `estimate_contrasts`, `estimate_slopes`, `estimate_predicted`, `estimate_grouplevel`)}
+#'
 #'
 #' @param x An `easystats` object.
 #' @param ... Other arguments passed to other functions.
@@ -69,3 +69,11 @@ print.visualisation_recipe <- function(x, ...) {
     cat("\n")
   }
 }
+
+
+
+#' @export
+plot.visualisation_recipe <- function(x, ...) {
+  insight::check_if_installed("see")
+  NextMethod()
+}
